@@ -19,10 +19,14 @@
 //!     .unwrap();
 //! ```
 
+#![deny(unsafe_code)]
+
 mod macros;
 
 pub mod assets;
-pub mod assets_metadata;
+pub mod assets_metadata {
+    pub use super::assets::assets_metadata::*;
+}
 pub mod config;
 pub mod controller;
 mod decorations;
@@ -44,7 +48,7 @@ pub(crate) mod syntax_mapping;
 mod terminal;
 pub(crate) mod wrapping;
 
-pub use pretty_printer::{Input, PrettyPrinter};
+pub use pretty_printer::{Input, PrettyPrinter, Syntax};
 pub use syntax_mapping::{MappingTarget, SyntaxMapping};
 pub use wrapping::WrappingMode;
 
